function [DistParam] = SetDistParam(PlantData);
% SetDistParam
% Define parameters for noise and disturbance
% M.Hirata and H.Uchida and T.Hara
% Ver.1.0, 2005-04-23
% Ver.1.1, 2005-04-26
% Ver.1.2, 2005-05-10, refine dist. parameters by H.Uchida
% Ver.1.3, 2005-05-12, refine dist. parameters by T.Hara
% Ver.1.4, 2005-05-13, refine flutter & RRO dist. by T.Hara
% Ver.2.0, 2006-02-13, change file name for new version
% Copyright (c) 2004-2006, MSS benchmark working group

% Data from plant model
rpm = PlantData.rpm;
Ts  = PlantData.Ts;
Tu  = PlantData.Tu;
Ty  = PlantData.Ty;
Fns = 1/Ts/2; % Nyquist freq. of PES sampling
Fnu = 1/Tu/2; % Nyquist freq. of plant input
Fny = 1/Ty/2; % Nyquist freq. of plant output

% Frequency vector
dF0s = 6; % Frequency resolution of PES
dF0u = 6; % Frequency resolution of plant input
dF0y = 6; % Frequency resolution of plant output
if ( (Fns/dF0s) ~= fix(Fns/dF0s) )
    error('Frequency resolution dF0s is not appropriate')
end
if ( (Fnu/dF0u) ~= fix(Fnu/dF0u) )
    error('Frequency resolution dF0u is not appropriate')
end
if ( (Fny/dF0y) ~= fix(Fny/dF0y) )
    error('Frequency resolution dF0y not appropriate')
end
Nums  = Fns/dF0s;
Numu  = Fnu/dF0u;
Numy  = Fny/dF0y;
dFs   = Fns/Nums;
dFu   = Fnu/Numu;
dFy   = Fny/Numy;
Freqs = dFs*(1:Nums)';
Frequ = dFu*(1:Numu)';
Freqy = dFy*(1:Numy)';

% The length of disturbance
num_sim_revolution = 1000;

% Scaling parameter
scl = sqrt(2*Ts);
% Sensor noise
AmpSensorNoise = 1.5e-2*scl; % unit:[Track], 1 sigma of Sensor Noise

% Force disturbance
AmpForceDist = 1.0e-4*scl; % unit:[A] at control input, 1 sigma of Torque Noise with sampling Ts

% Flutter & Suspension etc.
% Flutter dist.
%   Mode   Freq.
%   (0,0)   900
%   (0,1)-  900-120
%   (0,1)+  900+120
%   (0,2)-  990-240
%   (0,2)+  990+240
%   (0,3)- 1440-360
%   (0,3)+ 1440+360
% Suspension etc.
%   Freq: 3000, 5000Hz
FlutterFreq       = [  750,  780,  900, 1020, 1080, 1230, 1800, 3000, 5000];
% FlutterFreqSigma  = [   40,   30,   30,   30,   40,   40,   40,   50,   50];
FlutterFreqZeta   = [ 0.01, 0.01, 0.01, 0.01,0.005, 0.01,0.005,0.002,0.002];
AmpFlutterDist    = [ 0.09, 0.17, 0.20, 0.17, 0.06, 0.09, 0.06, 0.06, 0.12]*scl;

% RRO
FreqRRO     = [ 1,  2,  3]*(rpm/60);  % Frequency [Hz]
AmpRRO      = [0.15, 0.03, 0.006];    % unit:[Track] at PES, Amplitude of each RRO component
if exist('RROSequence.mat','file')
    load RROSequence;
else
    RROSequence = zeros(PlantData.num_servo,1);
end

% The length of simulation
DistParam.num_sim_revolution = num_sim_revolution;
% Frequency vector
DistParam.Nums              = Nums;
DistParam.Numu              = Numu;
DistParam.Numy              = Numy;
DistParam.dFs               = dFs;
DistParam.dFu               = dFu;
DistParam.dFy               = dFy;
DistParam.Freqs             = Freqs;
DistParam.Frequ             = Frequ;
DistParam.Freqy             = Freqy;
% Sensor noise
DistParam.AmpSensorNoise    = AmpSensorNoise;
% Force disturbance
DistParam.AmpForceDist      = AmpForceDist;
% Flutter disturbance
DistParam.AmpFlutterDist    = AmpFlutterDist;
DistParam.FlutterFreq       = FlutterFreq;
% DistParam.FlutterFreqSigma  = FlutterFreqSigma; % used ???
DistParam.FlutterFreqZeta   = FlutterFreqZeta;
% RRO disturbance
DistParam.FreqRRO           = FreqRRO;
DistParam.AmpRRO            = AmpRRO;
DistParam.RROSequence       = RROSequence;
% Seeds for random signal
DistParam.Seed_ForceDist    = 1;
DistParam.Seed_SensorNoise  = 2;
DistParam.Seed_FlutterDist  = 3;
DistParam.Seed_RRODist      = 4;

%% EOF of SetDistParam.m
