function [PlantData] = SetPlantModel(options);
% SetPlantModel.m
% M.Hirata and H.Uchida and T.Hara
% Ver.1.0, 2005-04-23
% Ver.1.1, 2005-05-02
% Ver.1.1, 2005-05-12, refine plant parameters by T.Hara
% Ver.1.2, 2005-05-16, refine perturbations of physical parameters by M.Hirata
% Ver.2.0, 2006-02-12, new mechanical vibration model
% Copyright (c) 2004-2005, MSS benchmark working group

% Options
if nargin == 0
    options.seekmode = 0;
end

% Plant parameters
m  = 1e-3;	      % Equivalent mass of head actuator [kg]
Tp = 2.54e-7;	  % Width of track [m] 100kTPI
% Lc = Rs/(2*pi*4e4); % Inductance of VCM
% Rc = 8;		  % Equivalent resistance of VCM [Ohm]
Kf = 1.0;	      % Equivalent Force constant [N/A] (0.9512 -> 1.0 ver.2)
Kg = Kf/m;	      % Input gain [m/(s^2A)]
Kp = 1/Tp*Kf/m;
DeltaKp = [-10, 10]/100; % Gain perturbation (percent)

% Rotation speed of disk and sampling time
rpm       = 7200;                % rotational speed
num_servo =  220;                % Number of servo per track
Ts        = 60/rpm/num_servo;    % Sampling time of Position Error Signal (PES)
Tc        = Ts;                  % Sampling time of control input
Ty        = Ts;                  % Sampling time at plant output
Tu        = Tc;                  % Sampling time at plant input
Td        = 10.0e-6;             % Input delay [s]

% Data of mechanical vibration modes
Fn   =       [   90,  3000,  4100,  5000,  7000, 12300, 16400]; % [Hz]
Zeta =       [  0.5,  0.01,  0.03,  0.01,  0.01,  0.005,  0.005];
Gain =       [  1.0,   -0.01,  -1.0,   0.3,  -1.0,   1.0,  -1.0];
if options.seekmode == 1
    Fn(1) = 0; Zeta(1) = 0;
end
% Perturbations for nominal values (multiplicative error)
DeltaFn =    [    0,     0,     0,     0,     0,     0,     0 ;
                  0,     1,   2.5,   0.5,   0.5,   0.5,   0.5 ;
                  0,    -2,    -5,    -2,    -2,    -2,    -2]/100; % percent
DeltaZeta =  [    0,     0,     0,     0,     0,     0,     0 ;
                  0,     0,     0,     0,   -50,   -50,   -50 ;
                  0,     0,     0,     0,   100,   100,   100]/100; % percent
DeltaGain =  [    0,     0,     0,     0,     0,     0,     0 ;
                  0,  -200,    20,  -200,     0,     0,     0]/100; % percent

% Nominal model (reduced-order)
[sys_plant_nominal] = make_plant(Fn(1), Zeta(1), Gain(1));

% Full-order model
[sys_plant_full] = make_plant( Fn, Zeta, Gain );

% Full-order model with variation
i_cnt = 1;
zz = Fn*0;
[ii1max,xxx] = size(DeltaFn);
[ii2max,xxx] = size(DeltaZeta);
[ii3max,xxx] = size(DeltaGain);
for ii1 = 1:ii1max
    for ii2 = 1:ii2max
        for ii3 = 1:ii3max
            if ( any(DeltaFn(ii1,:)~=zz) | any(DeltaZeta(ii2,:)~=zz) | any(DeltaGain(ii3,:)~=zz))
                f = Fn + Fn.*DeltaFn(ii1,:);
                z = Zeta + Zeta.*DeltaZeta(ii2,:);
                g = Gain + Gain.*DeltaGain(ii3,:);
                [sys_plant_full_pert(1,1,i_cnt)] = make_plant( f, z, g );
                i_cnt = i_cnt+1;
            else
                % disp('SKIP')
                % [ii1, ii2, ii3]
            end
        end
    end
end

% Plant models
sys_Pn     = (1/Tp)*sys_plant_nominal*Kg;    % nominal
sys_Pf     = (1/Tp)*sys_plant_full*Kg;       % full-order
sys_Pfpert = (1/Tp)*sys_plant_full_pert*Kg;  % full-order w/ variation

% Set input delay property
set(sys_Pn,'InputDelay',Td);
set(sys_Pf,'InputDelay',Td);
set(sys_Pfpert,'InputDelay',Td);

% Physical parameters
PlantData.m          = m;
PlantData.Tp         = Tp;
% PlantData.Rs         = Rc;
% PlantData.Ls         = Ls;
PlantData.Kf         = Kf;
PlantData.Kg         = Kg;
PlantData.Kp         = Kp;
% PES
PlantData.rpm        = rpm;
PlantData.num_servo  = num_servo; % fixed (Ver.1.1)
PlantData.Ts         = Ts;
PlantData.Tc         = Tc;
PlantData.Ty         = Ty; % Ver.2.0
PlantData.Tu         = Tu; % Ver.2.0
PlantData.Td         = Td;
% Mechanical resonance modes
PlantData.MechFn     = Fn;
PlantData.MechZeta   = Zeta;
PlantData.MechGain   = Gain;
% PlantData.MechPRS    = delta_primary_resonance;
% Plant models
PlantData.sys_Pn     = sys_Pn;
PlantData.sys_Pf     = sys_Pf;
PlantData.sys_Pfpert = sys_Pfpert;
% Plant models (Input: [m/s^2], output: [m])
PlantData.sys_plant_nominal   = sys_plant_nominal;
PlantData.sys_plant_full      = sys_plant_full;
PlantData.sys_plant_full_pert = sys_plant_full_pert;
% Model perturbation
PlantData.DeltaKp         = DeltaKp;
PlantData.MechDeltaFn     = DeltaFn;
PlantData.MechDeltaZeta   = DeltaZeta;
PlantData.MechDeltaGain   = DeltaGain;

%% EOF of SetPlantModel.m
